elasticity = function(matr) {
  
  w = eigen(matr)$vectors[,1]
  #w = w / sum(w)
  v = eigen(t(matr))$vectors[,1]
  #v = v / sum(v)
  l = eigen(matr)$values[1]
  
  S = (v %*% t(w)) / (v %*% w)[1]
  #S = Conj(v) %*% t(w) %*% diag((t(Conj(v)) %*% w)[1], 5)
  E = (S*matr)/l
  
  return(list(S = S, E = E))
  
}

matrixFromRates = function(rates) {
  
  m = matrix(0, nrow = 6, ncol = 6)
  dimnames(m) = list(c("S", "J1", "J2", "J3", "B", "F"), c("S", "J1", "J2", "J3", "B", "F"))
  
  m["J1", "S"] = with(rates, s_s)
  m["J2", "J1"] = with(rates, s_j1)
  m["J2", "J2"] = with(rates, (s_j2 - s_j2^(alpha)) / (1 - s_j2^alpha))
  m["J3", "J2"] = with(rates, (s_j2^alpha - s_j2^(alpha+1)) / (1 - s_j2^alpha))
  m["J3", "J3"] = with(rates, s_j3 * (1 - f_j3))
  m["F", "J3"] = with(rates, s_j3 * f_j3)
  m["B", "B"] = with(rates, s_b * (1 - f_b))
  m["F", "B"] = with(rates, s_b * f_b)
  m["B", "F"] = with(rates, s_f * (1 - f_f))
  m["F", "F"] = with(rates, s_f * f_f)
  m["S", "F"] = with(rates, s_f * r_f)
  
  return(m)

}

iter.matr = function(data) {
  
  # a function for iteratively calculating survival rates for seedlings
  # however, we do not implement it because it produced survival estimates greater than 1
  
  d = data
  lamb = 1
  
  while (abs(eigen(d$matr)$value[1] - lamb) > 1e-4) {
    
    lamb = eigen(d$matr)$value[1]    
    d$rates$s_j1 = d$rates$s_j1 / lamb
    d$matr = matrixFromRates(d$rates)
    
  }
  
  return(d)
  
}

sim.seq = function(freq, length) {
  ### this function generates a burn sequence with burns of frequency 'freq'
  ### freq is a float, mean annual probability of fires
  ### length is an integer for number of years to simulate
  # generate a fixed number of fires (reduces variance in our estimates hopefully)
  nfires = ceiling(length * freq)
  # randomly puts nfires fires (1s) into a sequence of length 'length'
  seq = sample(c(rep(1, nfires), rep(0, length - nfires)))
  # this loop puts in 1 and 2 years post-burn into data (2 and 3, respectively)
  for (i in 2:length) {
    if (!seq[i] & seq[i-1] == 1) { seq[i] = 2
    } else if (!seq[i] & seq[i-1] == 2) seq[i] = 3
  }
  return(seq)
}

matr.prod = function(m) {
  ### a wrapper function which takes in a matrix of matrices and gives the ordered product
  ### m is 25 x M, a row for each matrix entry (out of 25) and M matrices (length of burn sequence)
  matr = diag(1, 6)
  for (x in 1:ncol(m)) matr = matrix(m[,x], nrow = 6) %*% matr
  return(matr)
}

# a wrapper function for easily sampling matrix indices
samp = function(x, y) ifelse(length(unlist(x[!is.na(x)])) < 2, x, sample(unlist(x[!is.na(x)]), y, replace = TRUE)) 


subs.rate = function(rate.name, rate.value, rates) {
  ### substitutes rate (rate.name) for sampled rate.value (array of values) into matrix
  rates[rate.name] = samp(rate.value)
  matr = matrixFromRates(rates = as.list(rates))
  return(matr %>% as.array)
}
