# README

### `01_data_inputs`

This directory holds data inputs for analysis.

Raw data used for estimating vital rates is currently accessible both in this subdirectory and through Dropbox links. Files and the scripts they are used in are described below.

In case of link breakage, raw data files can be found here:

http://echinaceaproject.org/data/nordstrom-fire-demography-2020/nordstrom_etal_2021_data/01_data_inputs/

For example, R can read the data file `adult_demography_for_MSMR.csv` with either of the following two lnes of code:

```
# from Dropbox link
dd = read.csv('https://www.dropbox.com/s/wxzerd9yytmoaxn/adult_demography_for_MSMR.csv?dl=1')
# downloaded from website
ww <- read.csv('http://echinaceaproject.org/data/nordstrom-fire-demography-2020/nordstrom_etal_2021_data/01_data_inputs/adult_demography_for_MSMR.csv')
```

This directory also includes `annual_climate_2000_2017.csv` with three climate indices for each year 2000 - 2017.
This file was derived from PRISM Data (https://prism.oregonstate.edu/) for a four km2 area surrounding most of our study area.
Annual estimates here were summaries of monthly temperature estimates, where the mean for a given year was the mean from July to June as described in Supporting Information of the paper.
These estimates were used as predictors in vital rate models for seedling recruitment, juvenile survival, and juvenile flowering.

Links and descriptions follow:

##### adult_demography_for_MSMR.csv
Dropbox link: `https://www.dropbox.com/s/wxzerd9yytmoaxn/adult_demography_for_MSMR.csv`
This file has longitudional data on adults in remnant populations between 1996 and 2016.
`aka` is an identifier for an adult plant, `site` denotes population, `year` is the year of the observation.
`ld` is observed alive during the observaton, `fl` is observed in flower (with an elongated stem).
`hdCt` was not used in analysis.
This file was used in the multi-stage mark recapture model to estimate survival of survival and flowering of basal and flowering plants (s_b, s_f, f_b, f_f in the paper).
See script `02_vital_rate_models/run_multistate_mark_recapture.R`.

##### high_juvenile_survival_for_matrix_models.csv
Dropbox link: `https://www.dropbox.com/s/5ed5hmi9k6fyjxa/high_juvenile_survival_census_for_matrix_models.csv`
This file has censuses of seedlings and juveniles from an experiment described in Wagenius et al. 2012 (Restoration Ecology).
It has the counts of plants sown from seed in experimental plots with varying burn frequencies.
This dataset is described as the "high juvenile survival census" in the paper.
It is used to estimate juvenile survival and juvenile flowering.
See scripts
`02_vital_rate_models/model_juv_survival_for_matrices.R` and
`02_vital_rate_models/model_juv_flowering_for_matrices.R`.

##### seedling_recruitment_for_matrix_models.csv
`https://www.dropbox.com/s/znycfs1ol20ts4z/seedling_recruitment_for_matrix_models.csv`
This file has seedling recruitment estimates in remnants between 2007 and 2013.
This data was collected by observing seedling recruitment within a ~50 cm radius of ~1200 adult plants.
This data was used to estimate seedling recruitment (r_f) for matrix models.
See script `02_vital_rate_models/model_seedling_recruitment_for_matrices.R`.

##### low_juvenile_survival_census_for_matrix_models.csv
`https://www.dropbox.com/s/0jm4hojh32cqg34/low_juvenile_survival_census_for_matrix_models.csv`
This file has censuses with longitudional records for seedlings and juvenile plants in remnants.
It is a continuation of observations from the seedling recruitment census outlined above.
It is called the "low juvenile survival vensus" in the paper and is used to estimate juvenile survival.
See script `02_vital_rate_models/model_juv_survival_for_matrices.R`.
