# Readme

### `02_vital_rate_models`

This directory has scripts used to estimate vital rates, and the effect of fire on vital rates where data allows.

Data is read in from Dropbox links. Column information for each datafile is provided in the script.
Posterior estimates (i.e., predicted vital rates) are exported to directory `03_vital_rate_posteriors`.

All analyses were run in Spring 2019 initially run with R 3.5.0.

##### Adult vital rates (s_b, s_f, f_b, f_f)

`run_multistage_mark_recapture.R`
Script for running the multi-stage mark recapture model. 
It formats the raw demographic data into a wide format useable for the model.
After preparing the data it runs the stan model, written in the following script:

`multistage_mark_recapture.stan`
This requires that you have Stan installed. Original script used Stan 2.19.1.
Model output from the R script is an .RData file housing all Stan models.

`extract_adult_rates_bayesian.R`
This is an R script for reading in the stan model outputs (.RData files) and subsampling the posterior estimates to export 100 vital rates for each combination of population and year.

Output exported to `03_vital_rate_posteriors`.
Original model output from 2019 and paper are
`03_vital_rate_posteriors/MSMR_raw_output_original.RData` and
`03_vital_rate_posteriors/adult_rates_bayesian_original.csv`.

These posterior estimates are used to create Figure 2 in the paper.

##### Seedling recruitment (r_f)

`model_seedling_recruitment_for_matrices.R`
Model fitting Bayesian models using brms (2.7.0).
Output (posterior subsamples) in `03_vital_rate_posteriors/recruit_estimates_bayesian_original.csv`.

##### Juvenile survival (s_s, s_j1, s_j2, s_j3)

Both high and low juvenile survival models are fit in the script:
`model_juv_survival_for_matrices.R`
using brms (2.7.0).
The high juvenile survival models are very slow to run.
Additionally, they are fit using a custom beta binomial link.
Changes to brms since the running of this model have rendered parts of this code obsolete.
Please see the following link which may be of use with updated versionf of Brms:
https://github.com/paul-buerkner/brms/blob/master/doc/brms_customfamilies.R

Outputs are
`03_vital_rate_posteriors/juv_surv_bayesian_hijuv_original.csv` and
`03_vital_rate_posteriors/juv_surv_bayesian_lojuv_original.csv`.

The first of these CSV files is used to create Figure 3 in the paper.

##### Juvenile flowering (f_j3)

Script fitting models with brms (2.7.0) and subsampling posterior estimates is
`model_juv_flowering_for_matrices.csv`

Output is
`03_vital_rate_posteriors/juv_flower_bayesian_original.csv`.

##### Package info

Typical session info for model runs:

> sessionInfo()

# R version 3.5.0 (2018-04-23)
# Platform: x86_64-apple-darwin15.6.0 (64-bit)
# Running under: macOS High Sierra 10.13.6
# 
# Matrix products: default
# BLAS: /System/Library/Frameworks/Accelerate.framework/Versions/A/Frameworks/vecLib.framework/Versions/A/libBLAS.dylib
# LAPACK: /Library/Frameworks/R.framework/Versions/3.5/Resources/lib/libRlapack.dylib
# 
# locale:
# [1] en_US.UTF-8/en_US.UTF-8/en_US.UTF-8/C/en_US.UTF-8/en_US.UTF-8
# 
# attached base packages:
# [1] stats     graphics  grDevices utils     datasets  methods   base     
# 
# other attached packages:
# [1] brms_2.7.0     Rcpp_1.0.0     tidyr_0.8.1    bindrcpp_0.2.2 dplyr_0.7.8    ggplot2_3.1.0 
# 
# loaded via a namespace (and not attached):
# [1] Brobdingnag_1.2-6    gtools_3.8.1         StanHeaders_2.17.2   threejs_0.3.1       
# [5] shiny_1.1.0          assertthat_0.2.0     stats4_3.5.0         yaml_2.1.19         
# [9] backports_1.1.2      pillar_1.3.0.9001    lattice_0.20-35      glue_1.3.0          
# [13] digest_0.6.18        RColorBrewer_1.1-2   promises_1.0.1       colorspace_1.3-2    
# [17] htmltools_0.3.6      httpuv_1.4.5         Matrix_1.2-14        plyr_1.8.4          
# [21] dygraphs_1.1.1.6     pkgconfig_2.0.2      rstan_2.17.3         purrr_0.2.5         
# [25] xtable_1.8-3         mvtnorm_1.0-8        scales_1.0.0         later_0.7.5         
# [29] tibble_1.4.99.9005   bayesplot_1.6.0      DT_0.4               withr_2.1.2         
# [33] shinyjs_1.0          lazyeval_0.2.1       magrittr_1.5         crayon_1.3.4        
# [37] mime_0.5             nlme_3.1-137         xts_0.11-1           colourpicker_1.0    
# [41] rsconnect_0.8.8      tools_3.5.0          loo_2.0.0            matrixStats_0.54.0  
# [45] stringr_1.3.1        munsell_0.5.0        compiler_3.5.0       rlang_0.3.1         
# [49] grid_3.5.0           ggridges_0.5.0       rstudioapi_0.7       htmlwidgets_1.2     
# [53] crosstalk_1.0.0      igraph_1.2.1         miniUI_0.1.1.1       base64enc_0.1-3     
# [57] labeling_0.3         codetools_0.2-15     gtable_0.2.0         inline_0.3.15       
# [61] abind_1.4-5          markdown_0.8         reshape2_1.4.3       R6_2.3.0            
# [65] gridExtra_2.3        rstantools_1.5.1     zoo_1.8-4            bridgesampling_0.6-0
# [69] bindr_0.1.1          shinystan_2.5.0      shinythemes_1.1.1    stringi_1.2.2       
# [73] parallel_3.5.0       tidyselect_0.2.5     coda_0.19-1  
