# Readme

Readme file for data and analysis scripts for the paper
"Fires slow population declines of a long-lived prairie plant through multiple vital rates"
by SW Nordstrom, AB Dykstra and S Wagenius.

### Directory structure

The analysis performed for this paper is complex with several parts.

Vital rate estimation occurs in the following directories:
`02_vital_rate_models` (scripts)
`03_vital_rate_posteriors` (output)

Matrix models are constructed in the following directories:
`04_matrix_fitting` (scripts)
`05_matrix_output` (output)

Analysis with matrix models occur in the following directories:
`06_analysis_scripts` (scripts)
`07_analysis_outputs` (output)

Script for recreating Figures from data are included in `08_figure_scripts`.

Even numbered directories house code for scripts while odd numbered scripts house data (inputs and outputs).

### Notes on scripts

All analyses were performed using R between February and April 2019.
Data processing and cleaning (as well as preliminary analysis) occurred between January 2017 and January 2019.
Here is the typical session info for model fitting:

```
# R version 3.5.0 (2018-04-23)
# Platform: x86_64-apple-darwin15.6.0 (64-bit)
# Running under: macOS High Sierra 10.13.6
# 
# Matrix products: default
# BLAS: /System/Library/Frameworks/Accelerate.framework/Versions/A/Frameworks/vecLib.framework/Versions/A/libBLAS.dylib
# LAPACK: /Library/Frameworks/R.framework/Versions/3.5/Resources/lib/libRlapack.dylib
# 
# locale:
# [1] en_US.UTF-8/en_US.UTF-8/en_US.UTF-8/C/en_US.UTF-8/en_US.UTF-8
# 
# attached base packages:
# [1] stats     graphics  grDevices utils     datasets  methods   base     
# 
# other attached packages:
# [1] brms_2.7.0     Rcpp_1.0.0     tidyr_0.8.1    bindrcpp_0.2.2 dplyr_0.7.8    ggplot2_3.1.0 
# 
# loaded via a namespace (and not attached):
# [1] Brobdingnag_1.2-6    gtools_3.8.1         StanHeaders_2.17.2   threejs_0.3.1       
# [5] shiny_1.1.0          assertthat_0.2.0     stats4_3.5.0         yaml_2.1.19         
# [9] backports_1.1.2      pillar_1.3.0.9001    lattice_0.20-35      glue_1.3.0          
# [13] digest_0.6.18        RColorBrewer_1.1-2   promises_1.0.1       colorspace_1.3-2    
# [17] htmltools_0.3.6      httpuv_1.4.5         Matrix_1.2-14        plyr_1.8.4          
# [21] dygraphs_1.1.1.6     pkgconfig_2.0.2      rstan_2.17.3         purrr_0.2.5         
# [25] xtable_1.8-3         mvtnorm_1.0-8        scales_1.0.0         later_0.7.5         
# [29] tibble_1.4.99.9005   bayesplot_1.6.0      DT_0.4               withr_2.1.2         
# [33] shinyjs_1.0          lazyeval_0.2.1       magrittr_1.5         crayon_1.3.4        
# [37] mime_0.5             nlme_3.1-137         xts_0.11-1           colourpicker_1.0    
# [41] rsconnect_0.8.8      tools_3.5.0          loo_2.0.0            matrixStats_0.54.0  
# [45] stringr_1.3.1        munsell_0.5.0        compiler_3.5.0       rlang_0.3.1         
# [49] grid_3.5.0           ggridges_0.5.0       rstudioapi_0.7       htmlwidgets_1.2     
# [53] crosstalk_1.0.0      igraph_1.2.1         miniUI_0.1.1.1       base64enc_0.1-3     
# [57] labeling_0.3         codetools_0.2-15     gtable_0.2.0         inline_0.3.15       
# [61] abind_1.4-5          markdown_0.8         reshape2_1.4.3       R6_2.3.0            
# [65] gridExtra_2.3        rstantools_1.5.1     zoo_1.8-4            bridgesampling_0.6-0
# [69] bindr_0.1.1          shinystan_2.5.0      shinythemes_1.1.1    stringi_1.2.2       
# [73] parallel_3.5.0       tidyselect_0.2.5     coda_0.19-1  
```

In particular, `brms`, `dplyr`, and `tidyr` were used heavily in analysis.
All plots are created using `ggplot2`.
The adult vital rate scripts were fit using `RStan` and `Stan` (Stan `2.19.1`).

Due to development in these packages, running these scripts with updated versions of these packages produces slightly different output (due in part to the stochasticity in the routines). 
This output is qualitatively similar if not identical to the original model output.
For completeness, we have included the original output files (from 2019) in this repository, with the suffix `_orignal` in the filename.

### Other notes

Some materials from this analysis were not included in the final analysis in the paper. 
This includes estimating population growth at an additional four (unburned control) sites as well as estimating population growth and contributions to population growth at additional burn frequencies.
These additional pieces of analysis are left in the code here for the benefit of future users of this data or analysis.

In the code we frequently use the term `site` for population. Consider these terms interchangeable.

Based on the advice of reviewers, we abbreviated the population codes NNWLF and RRXDC to NNW and RDC, respectively, in figures. However, the codes NNWLF and RRXDC appear frequently in code.

### Raw data

Raw data is currently accessible via Dropbox links. In the case of link breakage, raw data files are also available on the Echinacea Project website: http://echinaceaproject.org/data/nordstrom-fire-demography-2020/nordstrom_etal_2021_data/01_data_inputs/

For example, R can read the data file `adult_demography_for_MSMR.csv` with either of the two lines of code:

```
dd = read.csv('https://www.dropbox.com/s/wxzerd9yytmoaxn/adult_demography_for_MSMR.csv?dl=1')
ww = read.csv('http://echinaceaproject.org/data/nordstrom-fire-demography-2020/nordstrom_etal_2021_data/01_data_inputs/adult_demography_for_MSMR.csv')
```

### Contact information.

For questions please first contact Scott Nordstrom (corresponding author).
scottwatsonnordstrom [at] gmail [dot] com

This repository was assembled and uploaded in May 2021.
